@@ -70,6 +70,7 @@ import logging
 from string import capwords
 
 from mmcif.api.DataCategory import DataCategory
+from rcsb.utils.dictionary.DictMethodSecStructUtils import DictMethodSecStructUtils
 
 logger = logging.getLogger(__name__)
 
@@ -93,12 +94,18 @@ class DictMethodEntryHelper(object):
         #
         rP = kwargs.get("resourceProvider")
         self.__commonU = rP.getResource("DictMethodCommonUtils instance") if rP else None
-        dapw = rP.getResource("DictionaryAPIProviderWrapper instance") if rP else None
-        self.__dApi = dapw.getApiByName("pdbx_core") if dapw else None
+        # dapw = rP.getResource("DictionaryAPIProviderWrapper instance") if rP else None
+        # self.__dApi = dapw.getApiByName("pdbx_core") if dapw else None
+        self.__dApi = kwargs.get("dictionaryApi", None)
+        if self.__dApi:
+            logger.debug("Loaded API for: %r", self.__dApi.getDictionaryTitle())
+        else:
+            logger.error("Missing dictionary API %r", kwargs)
         #
         self.__crP = rP.getResource("CitationReferenceProvider instance") if rP else None
         self.__jtaP = rP.getResource("JournalTitleAbbreviationProvider instance") if rP else None
         #
+        self.__ssU = DictMethodSecStructUtils(rP, raiseExceptions=self._raiseExceptions)
         # logger.debug("Dictionary entry method helper init")
 
     def echo(self, msg):
@@ -726,7 +733,9 @@ class DictMethodEntryHelper(object):
         try:
             logger.debug("Starting with %r %r %r", dataContainer.getName(), catName, kwargs)
             # Exit if source categories are missing
-            if not (dataContainer.exists("exptl") and dataContainer.exists("entity")):
+            if not (dataContainer.exists("entity") and dataContainer.exists("entry")):
+                return False
+            if not (dataContainer.exists("exptl") or dataContainer.exists("ma_model_list")):
                 return False
             #
             # Create the new target category rcsb_entry_info
@@ -739,10 +748,20 @@ class DictMethodEntryHelper(object):
             # --------------------------------------------------------------------------------------------------------
             #  Filter experimental methods
             #
-            xObj = dataContainer.getObj("exptl")
-            entryId = xObj.getValue("entry_id", 0)
-            methodL = xObj.getAttributeValueList("method")
-            methodCount, expMethod = self.__commonU.filterExperimentalMethod(methodL)
+            methodCount = 0
+            expMethod = None
+            if dataContainer.exists("exptl"):
+                xObj = dataContainer.getObj("exptl")
+                entryId = xObj.getValue("entry_id", 0)
+                methodL = xObj.getAttributeValueList("method")
+                methodCount, expMethod = self.__commonU.filterExperimentalMethod(methodL)
+            elif dataContainer.exists("ma_model_list"):
+                tObj = dataContainer.getObj("entry")
+                entryId = tObj.getValue("id", 0)
+                mObj = dataContainer.getObj("ma_model_list")
+                methodL = mObj.getAttributeUniqueValueList("model_type")
+                methodCount, expMethod = self.__commonU.filterExperimentalMethod(methodL)
+            #
             cObj.setValue(entryId, "entry_id", 0)
             cObj.setValue(expMethod, "experimental_method", 0)
             cObj.setValue(methodCount, "experimental_method_count", 0)
@@ -890,7 +909,7 @@ class DictMethodEntryHelper(object):
             cObj.setValue(bCountsD["metalc"], "inter_mol_metalic_bond_count", 0)
             cObj.setValue(bCountsD["covale"], "inter_mol_covalent_bond_count", 0)
             #
-            cisPeptideD = self.__commonU.getCisPeptides(dataContainer)
+            cisPeptideD = self.__ssU.getCisPeptides(dataContainer)
             cObj.setValue(len(cisPeptideD), "cis_peptide_count", 0)
             #
             # This is reset in anothor method - filterSourceOrganismDetails()
